@@ -35,12 +35,10 @@ class Experiment_Setup:
         if 'years' in dir(self):
             self.years=self.years.split(',')
 
-        self.runscript_file=self.runscripts_dir+'/'+'_'.join([self.diagnostic,
-                                                            self.model,
-                                                            self.center,
-                                                            self.rip,
-                                                            self.experiment,
-                                                            '-'.join(self.years)])
+        desc_list=[self.diagnostic,self.model,self.center,self.rip,self.experiment,'-'.join(self.years)]
+        if self.month: desc_list.append(str(self.month))
+        self.description='_'.join(desc_list)
+        self.runscript_file=self.runscripts_dir+'/'+self.description
 
     def prepare_scripts(self):
         """ Prepares the scripts for bash launch """
@@ -51,11 +49,11 @@ class Experiment_Setup:
         if self.pbs_expt:
             #If the script is expected to be submitted to a PBS queue, output the required headers:
 	    if self.queue != None: out.writei('#PBS -q {0}\n'.format(self.queue))
-            #out.writei('#PBS -l nodes=1:ppn={0},walltime={1}\n'.format(max(self.dim_async,self.m_async),self.walltime))
-            out.writei('#PBS -l nodes=1:ppn={0}\n'.format(max(self.dim_async,self.m_async)))
-            out.writei('#PBS -N {0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.rip,self.experiment))
-            out.writei('#PBS -o {5}/pbs_out/{0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.rip,self.experiment,self.output_dir))
-            out.writei('#PBS -e {5}/pbs_err/{0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.rip,self.experiment,self.output_dir))
+            out.writei('#PBS -l nodes=1:ppn={0},walltime={1}\n'.format(max(self.m_async,self.ppn),self.walltime))
+            #out.writei('#PBS -l nodes=1:ppn={0}\n'.format(self.m_async))
+            out.writei('#PBS -N {0}\n'.format(self.description))
+            out.writei('#PBS -o {1}/pbs_out/{0}\n'.format(self.description,self.output_dir))
+            out.writei('#PBS -e {1}/pbs_err/{0}\n'.format(self.description,self.output_dir))
 
         #Put the header to the diagnostic:
         out.writei('\n')
@@ -121,6 +119,31 @@ class Experiment_Setup:
         structure_out_with_cmip5_drs(self,out)
         out.open.close()
 
+def ramdisk_protection(self,out):
+    out.writei('function cleanup_ramdisk {\n')
+    out.inc_indent()
+    out.writei('echo -n "Cleaning up ramdisk directory {0} on "\n'.format(self.temp_dir))
+    out.writei('date\n')
+    out.writei('rm -rf {0}\n'.format(self.temp_dir))
+    out.writei('echo -n "done at "\n')
+    out.writei('date\n')
+    out.dec_indent()
+    out.writei('}')
+
+    out.writei('function trap_term {\n')
+    out.inc_indent()
+    out.writei('echo -n "Trapped term (soft kill) signal on "\n')
+    out.writei('date\n')
+    out.writei('cleanup_ramdisk\n')
+    out.writei('exit\n')
+    out.dec_indent()
+    out.writei('}\n')
+
+    out.writei('#trap the termination signal, and call the function trap_term when\n')
+    out.writei('# that happens, so results may be saved.\n')
+    out.writei('trap "trap_term" TERM\n')
+    return self
+
 def structure_out_with_cmip5_drs(self,out):
     #code to structure the output with the CMIP5 DRS:
     out.writei('#THE LAST PART OF THIS SCRIPT REORGANIZES THE OUTPUT TO CONFORM WITH THE CMIP5 DRS:\n')
@@ -282,6 +305,7 @@ def end_monthly_loop(self,out,line):
     out.dec_indent()
     out.writei('fi\n')
 
+    ramdisk_protection(self,out)
     #Process the monthly_scripts
     if self.debug:
         out.writei('ls ${CDB_TEMP_DIR}/script_????_??.sh | parallel --tmpdir ${CDB_OUT_DIR} --tty "bash {}; rm {}"\n')
@@ -329,14 +353,16 @@ def main():
                              BEWARE! Asynchronous options are largely untested!")
     proc_group.add_argument("--m_async",dest="m_async",
                       default=1,
-                      help="Uses the specified # of processors for the asynchronous processing of months.\n\
-                            be used with --dim_async. Requires NCO version 4.0.0 and above, gnu-parallel.")
+                      help="Uses the specified # of processors for the asynchronous processing of months.")
+    proc_group.add_argument("--ppn",dest="ppn",
+                      default=1,
+                      help="Processors per nodes. Set to max(M_ASYNC,PPN).")
     proc_group.add_argument("-P","--pbs_expt",dest="pbs_expt",
                       default=False, action="store_true",
                       help="Prepare a pbs header for each model/rip/experiment")
     proc_group.add_argument("-w","--walltime",dest="walltime",
                       default="1:00:00",
-                      help="pbs job walltime. Inactive for now: Determined by queue")
+                      help="pbs job walltime.")
     proc_group.add_argument("-q","--queue",dest="queue",
                       default=None,
                       help="PBS queue type")
@@ -375,7 +401,7 @@ def main():
 
     diag_desc=paths_dict.header
 
-    if options.submit: print('Submitting jobs using qsub -q '+options.queue)
+    if options.submit: print('Submitting jobs using qsub ')
 
     for dir_to_set in ['output_dir','diagnostic_dir','runscripts_dir','temp_dir']:
         dir_path=os.path.expanduser(
@@ -396,30 +422,45 @@ def main():
     else:
         options.months_list=range(1,13)
 
+    if options.month:
+        options.months_list=[options.month]
+
     for simulation in paths_dict.simulations_list():
         options.center, options.model, options.rip = simulation
         for exp in diag_desc['experiment_list'].keys():
             options.experiment=exp
             period_list=diag_desc['experiment_list'][exp]
             if not isinstance(period_list,list): period_list=[period_list]
-
-            for period in period_list:
-                options.years=period
-
-                #PREPARE SCRIPTS
-                experiment = Experiment_Setup(options)
-                experiment.prepare_scripts()
-
-                #options.file_type='HTTPServer'
-                #print cdb_query_archive.list_unique_paths(paths_dict,options)
-
-                if options.run:
-                    os.system('bash '+experiment.runscript_file)
-                elif options.submit:
-                    os.system('qsub '+experiment.runscript_file)
+            map(lambda x:period_script(x,options),period_list)
 
     if not options.run and not options.submit:
         print 'Scripts are available in '+options.runscripts_dir
 
+def period_script(period,options):
+    options.years=set_period(period,options)
+
+    #PREPARE SCRIPTS
+    experiment = Experiment_Setup(options)
+    experiment.prepare_scripts()
+
+    #options.file_type='HTTPServer'
+    #print cdb_query_archive.list_unique_paths(paths_dict,options)
+
+    if options.run:
+        os.system('bash '+experiment.runscript_file)
+    elif options.submit:
+        os.system('qsub '+experiment.runscript_file)
+
+def set_period(period,options):
+    if not options.year:
+        return period
+    else:
+        years_range=[int(item) for item in period.split(',')]
+        years_range[1]+=1
+        if options.year not in range(*years_range):
+            return period
+        else:
+            return ','.join([str(options.year),str(options.year)])
+
 if __name__ == "__main__":
     main()
