@@ -3,7 +3,6 @@ import copy
 import warnings
 from pyesgf.search import SearchConnection
 
-import database_utils
 from tree_utils import File_Expt
 
 import multiprocessing as mproc
@@ -40,6 +39,7 @@ def experiment_variable_search(pointers,search_path,file_type_list,options,
 
     pointers.file_expt.experiment=experiment
     pointers.file_expt.var=var_name
+    pointers.file_expt.mip=mip
     pointers.file_expt.realm=realm
     pointers.file_expt.frequency=frequency
     pointers.file_expt.search=search_path
@@ -55,42 +55,40 @@ def experiment_variable_search(pointers,search_path,file_type_list,options,
     #    pool.close()
     #else:
 
-    file_list_remote=map(lambda x: get_urls(x,file_type_list,var_name),ctx.search(variable=var_name))
+    try:
+        file_list_found=ctx.search(variable=var_name)
+    except:
+        warnings.warn('Search path {0} is unresponsive at the moment'.format(search_path))
+        file_list_found=[]
+    file_list_remote=map(lambda x: get_urls(x,file_type_list,var_name),file_list_found)
     file_list_remote=[item for sublist in file_list_remote for item in sublist]
    
-    for url in file_list_remote:
-        pointers.file_expt.file_type=url[0]
-        url_name=url[1]
-        if pointers.file_expt.file_type==url[0] in remote_file_types:
-            file_description=url_name.split('/')[-10:-1]
-            known_description=[ file_description[ind] for ind in [2,3,4,5,8] ]
-            if known_description==[experiment,frequency,realm,mip,var_name]:
-                if url[2]:
-                    pointers.file_expt.path=url_name+'|'+url[2]
-                else:
-                    pointers.file_expt.path=url_name
-                pointers.file_expt.center=file_description[0]
-                pointers.file_expt.model=file_description[1]
-                pointers.file_expt.rip=file_description[6]
-                pointers.file_expt.mip=file_description[5]
-                pointers.file_expt.version=file_description[7]
-                if url_name and pointers.file_expt.version[1:]!='atest':
-                    pointers.add_item()
-        elif pointers.file_expt.file_type==url[0] in ['OPeNDAP']:
-            file_description=url[2]
-            variable=file_description[-2]
-            if variable==var_name:
-                pointers.file_expt.path=url_name
-                pointers.file_expt.center=file_description[-9]
-                pointers.file_expt.model=file_description[-8]
-                pointers.file_expt.rip=file_description[-3]
-                pointers.file_expt.mip=file_description[-4]
-                pointers.file_expt.version='v'+file_description[-1].replace('v','')
-                if url_name and pointers.file_expt.version[1:]!='atest':
-                    pointers.add_item()
+    #for file in file_list_remote: pointers=record_url(file,pointers)
+    map(lambda x: record_url(x,pointers),file_list_remote)
     print 'Done searching for variable '+var_name
     return
 
+def record_url(remote_file_desc,pointers):
+    pointers.file_expt.path=remote_file_desc['url']
+    if remote_file_desc['file_type'] in remote_file_types and remote_file_desc['checksum']:
+        pointers.file_expt.path+='|'+remote_file_desc['checksum']
+
+    for val in ['file_type','center','model','rip','version']:
+        setattr(pointers.file_expt,val,remote_file_desc[val])
+
+    #Convert unicode to string:
+    for val in dir(pointers.file_expt):
+        if val[0]!='_' and val!='case_id':
+            setattr(pointers.file_expt,val,str(getattr(pointers.file_expt,val)))
+
+    known_fields=['experiment','var','frequency','realm','mip']
+    list_of_knowns=[ getattr(pointers.file_expt,field) for field in known_fields] 
+    list_of_retrieved=[ remote_file_desc[field] for field in known_fields] 
+    if (remote_file_desc['version'][1:]!='atest' and 
+        len([i for i,j in zip(list_of_knowns,list_of_retrieved) if i==j])==len(list_of_knowns)):
+        pointers.add_item()
+    return pointers
+
 def get_urls(result,file_type_list,var_name):
     file_list_remote=[]
     if len(set(file_type_list).intersection(set(remote_file_types)))>0:
@@ -111,30 +109,51 @@ def get_urls(result,file_type_list,var_name):
             file_list_remote.append(get_url_opendap(item))
     return file_list_remote
 
+correspondence_dict={'experiment':'experiment',
+                     'mip':'cmor_table', 
+                     'realm':'realm', 
+                     'version':'version', 
+                     'rip':'ensemble',
+                     'frequency':'time_frequency', 
+                     'var':'variable', 
+                     'checksum':'checksum',
+                     'model':'model',
+                     'center':'institute'
+                     }
+
 def get_url_remote(item,file_type_list):
-    url_name=(None,None,None)
+    url_name=[]
     try:
         keys_list=item.urls.viewkeys()
     except:
         keys_list=[]
 
     for key in set(keys_list).intersection(file_type_list):
+        file_info=dict()
+        file_info['file_type']=key
         try:
-            checksum=item.checksum
+            file_info['url']=item.urls[key][0][0]
         except:
-            checksum=None
-        try:
-            url_name=(key,item.urls[key][0][0],checksum)
-        except:
-            url_name=(None,None,None)
-    if not isinstance(url_name,list): url_name=[url_name]
+            file_info['url']=None
+        for val in correspondence_dict.keys():
+            try:
+                file_info[val]=item.json[correspondence_dict[val]]
+                if isinstance(file_info[val],list): file_info[val]=str(file_info[val][0])
+            except:
+                file_info[val]=None
+        url_name.append(file_info)
     return url_name
 
 def get_url_opendap(item):
+    url_name['file_type']='OPeNDAP'
     try:
-        url_name=('OPeNDAP',item.opendap_url,item.json['title'].split('.aggregation')[0].split('.'))
+        url_name['url']=item.opendap_url
     except:
-        url_name=(None,None,None)
-    #if not isinstance(url_name,list): url_name=[url_name]
+        url_name['url']=None
+    for val in correspondence_dict.keys():
+        try:
+            url_name[val]=item.json[correspondence_dict[val]]
+        except:
+            url_name[val]=None
     return url_name
 
